@@ -1,11 +1,16 @@
 # -*- coding: utf-8 -*-
-'''
-Created : 2015-04-03
+#
+# Created : 2015-04-03
+#
+# @author: Eric Lapouyade
 
-@author: Eric Lapouyade
-'''
-
-__version__ = '0.0.9'
+__version__ = '0.1.1'
+__author__ = 'Eric Lapouyade'
+__copyright__ = 'Copyright 2015, python-textops project'
+__credits__ = ['Eric Lapouyade']
+__license__ = 'LGPL'
+__maintainer__ = 'Eric Lapouyade'
+__status__ = 'Beta'
 
 import logging
 
@@ -21,6 +26,6 @@ logger.addHandler(NullHandler())
 
 from base import TextOp, WrapOpIter, WrapOpYield, add_textop, add_textop_iter, \
                  add_textop_yield, StrExt, UnicodeExt, ListExt, DictExt, NoAttrDict, NoAttr, \
-                 activate_debug
+                 DefaultFormatter, activate_debug
 import ops
 from ops import *
